@@ -80,11 +80,6 @@ fn main() {
 
     let mut bindings = bindgen::Builder::default().header("wrapper.h");
 
-    #[cfg(windows)]
-    {
-        bindings = bindings.clang_args(["-x", "c++"]);
-    }
-
     if let Some(include_path) = clang_extra_include {
         bindings = bindings.clang_arg(format!("-I{}", include_path));
     }
